# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class RuntimeConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    openapi_types = {
        "asn": "int",
        "topology_name": "str",
        "topology_checksum": "str",
        "manager_id": "int",
        "ntp_hosts": "str",
        "vns3_version": "str",
        "licensed": "bool",
        "overlay_ipaddress": "str",
        "peered": "bool",
        "public_ipaddress": "str",
        "private_ipaddress": "str",
        "security_token": "str",
    }

    attribute_map = {
        "asn": "asn",
        "topology_name": "topology_name",
        "topology_checksum": "topology_checksum",
        "manager_id": "manager_id",
        "ntp_hosts": "ntp_hosts",
        "vns3_version": "vns3_version",
        "licensed": "licensed",
        "overlay_ipaddress": "overlay_ipaddress",
        "peered": "peered",
        "public_ipaddress": "public_ipaddress",
        "private_ipaddress": "private_ipaddress",
        "security_token": "security_token",
    }

    def __init__(
        self,
        asn=None,
        topology_name=None,
        topology_checksum=None,
        manager_id=None,
        ntp_hosts=None,
        vns3_version=None,
        licensed=None,
        overlay_ipaddress=None,
        peered=None,
        public_ipaddress=None,
        private_ipaddress=None,
        security_token=None,
    ):  # noqa: E501
        """RuntimeConfig - a model defined in OpenAPI"""  # noqa: E501

        self._asn = None
        self._topology_name = None
        self._topology_checksum = None
        self._manager_id = None
        self._ntp_hosts = None
        self._vns3_version = None
        self._licensed = None
        self._overlay_ipaddress = None
        self._peered = None
        self._public_ipaddress = None
        self._private_ipaddress = None
        self._security_token = None
        self.discriminator = None

        if asn is not None:
            self.asn = asn
        if topology_name is not None:
            self.topology_name = topology_name
        if topology_checksum is not None:
            self.topology_checksum = topology_checksum
        if manager_id is not None:
            self.manager_id = manager_id
        if ntp_hosts is not None:
            self.ntp_hosts = ntp_hosts
        if vns3_version is not None:
            self.vns3_version = vns3_version
        if licensed is not None:
            self.licensed = licensed
        if overlay_ipaddress is not None:
            self.overlay_ipaddress = overlay_ipaddress
        if peered is not None:
            self.peered = peered
        if public_ipaddress is not None:
            self.public_ipaddress = public_ipaddress
        if private_ipaddress is not None:
            self.private_ipaddress = private_ipaddress
        if security_token is not None:
            self.security_token = security_token

    @property
    def asn(self):
        """Gets the asn of this RuntimeConfig.  # noqa: E501

        Autonomous system number for controller if peered  # noqa: E501

        :return: The asn of this RuntimeConfig.  # noqa: E501
        :rtype: int
        """
        return self._asn

    @asn.setter
    def asn(self, asn):
        """Sets the asn of this RuntimeConfig.

        Autonomous system number for controller if peered  # noqa: E501

        :param asn: The asn of this RuntimeConfig.  # noqa: E501
        :type: int
        """

        self._asn = asn

    @property
    def topology_name(self):
        """Gets the topology_name of this RuntimeConfig.  # noqa: E501


        :return: The topology_name of this RuntimeConfig.  # noqa: E501
        :rtype: str
        """
        return self._topology_name

    @topology_name.setter
    def topology_name(self, topology_name):
        """Sets the topology_name of this RuntimeConfig.


        :param topology_name: The topology_name of this RuntimeConfig.  # noqa: E501
        :type: str
        """

        self._topology_name = topology_name

    @property
    def topology_checksum(self):
        """Gets the topology_checksum of this RuntimeConfig.  # noqa: E501


        :return: The topology_checksum of this RuntimeConfig.  # noqa: E501
        :rtype: str
        """
        return self._topology_checksum

    @topology_checksum.setter
    def topology_checksum(self, topology_checksum):
        """Sets the topology_checksum of this RuntimeConfig.


        :param topology_checksum: The topology_checksum of this RuntimeConfig.  # noqa: E501
        :type: str
        """

        self._topology_checksum = topology_checksum

    @property
    def manager_id(self):
        """Gets the manager_id of this RuntimeConfig.  # noqa: E501

        This managers ID in peered topology  # noqa: E501

        :return: The manager_id of this RuntimeConfig.  # noqa: E501
        :rtype: int
        """
        return self._manager_id

    @manager_id.setter
    def manager_id(self, manager_id):
        """Sets the manager_id of this RuntimeConfig.

        This managers ID in peered topology  # noqa: E501

        :param manager_id: The manager_id of this RuntimeConfig.  # noqa: E501
        :type: int
        """

        self._manager_id = manager_id

    @property
    def ntp_hosts(self):
        """Gets the ntp_hosts of this RuntimeConfig.  # noqa: E501

        NTP host endpoints, whitespace delimited  # noqa: E501

        :return: The ntp_hosts of this RuntimeConfig.  # noqa: E501
        :rtype: str
        """
        return self._ntp_hosts

    @ntp_hosts.setter
    def ntp_hosts(self, ntp_hosts):
        """Sets the ntp_hosts of this RuntimeConfig.

        NTP host endpoints, whitespace delimited  # noqa: E501

        :param ntp_hosts: The ntp_hosts of this RuntimeConfig.  # noqa: E501
        :type: str
        """

        self._ntp_hosts = ntp_hosts

    @property
    def vns3_version(self):
        """Gets the vns3_version of this RuntimeConfig.  # noqa: E501


        :return: The vns3_version of this RuntimeConfig.  # noqa: E501
        :rtype: str
        """
        return self._vns3_version

    @vns3_version.setter
    def vns3_version(self, vns3_version):
        """Sets the vns3_version of this RuntimeConfig.


        :param vns3_version: The vns3_version of this RuntimeConfig.  # noqa: E501
        :type: str
        """

        self._vns3_version = vns3_version

    @property
    def licensed(self):
        """Gets the licensed of this RuntimeConfig.  # noqa: E501


        :return: The licensed of this RuntimeConfig.  # noqa: E501
        :rtype: bool
        """
        return self._licensed

    @licensed.setter
    def licensed(self, licensed):
        """Sets the licensed of this RuntimeConfig.


        :param licensed: The licensed of this RuntimeConfig.  # noqa: E501
        :type: bool
        """

        self._licensed = licensed

    @property
    def overlay_ipaddress(self):
        """Gets the overlay_ipaddress of this RuntimeConfig.  # noqa: E501

        This managers overlay IP in peered topology  # noqa: E501

        :return: The overlay_ipaddress of this RuntimeConfig.  # noqa: E501
        :rtype: str
        """
        return self._overlay_ipaddress

    @overlay_ipaddress.setter
    def overlay_ipaddress(self, overlay_ipaddress):
        """Sets the overlay_ipaddress of this RuntimeConfig.

        This managers overlay IP in peered topology  # noqa: E501

        :param overlay_ipaddress: The overlay_ipaddress of this RuntimeConfig.  # noqa: E501
        :type: str
        """

        self._overlay_ipaddress = overlay_ipaddress

    @property
    def peered(self):
        """Gets the peered of this RuntimeConfig.  # noqa: E501


        :return: The peered of this RuntimeConfig.  # noqa: E501
        :rtype: bool
        """
        return self._peered

    @peered.setter
    def peered(self, peered):
        """Sets the peered of this RuntimeConfig.


        :param peered: The peered of this RuntimeConfig.  # noqa: E501
        :type: bool
        """

        self._peered = peered

    @property
    def public_ipaddress(self):
        """Gets the public_ipaddress of this RuntimeConfig.  # noqa: E501


        :return: The public_ipaddress of this RuntimeConfig.  # noqa: E501
        :rtype: str
        """
        return self._public_ipaddress

    @public_ipaddress.setter
    def public_ipaddress(self, public_ipaddress):
        """Sets the public_ipaddress of this RuntimeConfig.


        :param public_ipaddress: The public_ipaddress of this RuntimeConfig.  # noqa: E501
        :type: str
        """

        self._public_ipaddress = public_ipaddress

    @property
    def private_ipaddress(self):
        """Gets the private_ipaddress of this RuntimeConfig.  # noqa: E501


        :return: The private_ipaddress of this RuntimeConfig.  # noqa: E501
        :rtype: str
        """
        return self._private_ipaddress

    @private_ipaddress.setter
    def private_ipaddress(self, private_ipaddress):
        """Sets the private_ipaddress of this RuntimeConfig.


        :param private_ipaddress: The private_ipaddress of this RuntimeConfig.  # noqa: E501
        :type: str
        """

        self._private_ipaddress = private_ipaddress

    @property
    def security_token(self):
        """Gets the security_token of this RuntimeConfig.  # noqa: E501

        Security token in peered topology  # noqa: E501

        :return: The security_token of this RuntimeConfig.  # noqa: E501
        :rtype: str
        """
        return self._security_token

    @security_token.setter
    def security_token(self, security_token):
        """Sets the security_token of this RuntimeConfig.

        Security token in peered topology  # noqa: E501

        :param security_token: The security_token of this RuntimeConfig.  # noqa: E501
        :type: str
        """

        self._security_token = security_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuntimeConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import json
import subprocess

from cohesivenet import util, CohesiveSDKException


def load_terraform_state(path_to_infra):
    """Load terraform state

    Arguments:
        path_to_infra {str} - full path to infra

    Returns:
        Dict
    """
    raw_result = ""
    try:
        with util.cd(path_to_infra):
            result = subprocess.run(
                ["terraform", "show", "-json"], stdout=subprocess.PIPE
            )
            raw_result = result.stdout.decode("utf-8")
            return json.loads(raw_result.strip())
    except json.decoder.JSONDecodeError:
        raise CohesiveSDKException("Failed to load result: %s" % raw_result)



import os
import time
from typing import Dict

from cohesivenet import (
    VNS3Client,
    data_types,
    CohesiveSDKException,
    ApiException,
    Logger,
    UrlLib3ConnExceptions,
    HTTPStatus,
)
from cohesivenet.macros import api_operations


def fetch_keyset_from_source(client, source, token, wait_timeout=180.0):
    """fetch_keyset_from_source Put keyset by providing source controller to download keyset. This
    contains logic that handles whether or not fetching from the source fails, typically due
    to a firewall or routing issue in the underlay network (e.g. security groups and route tables).

    Pseudo-logic:
        PUT new keyset request to fetch from remote controller
        if keyset exists or already in progress, fail immediately as its unexpected
        if PUT succees:
            wait:
                if a new successful put returns: that indicates failure to download from source. return 400
                if timeout: that indicates controller is rebooting, return wait for keyset
                if keyset already exists, wait to ensure keyset  exists, then return keyset details

    Arguments:
        source {str} - host controller to fetch keyset from
        token {str} - secret token used when generating keyset
        wait_timeout {float} - timeout for waiting for keyset and while polling for download failure (default: 1 min)

    Raises:
        e: [description]
    """
    failure_error_str = (
        "Failed to fetch keyset for source. This typically due to a misconfigured "
        "firewall or routing issue between source and client controllers."
    )

    try:
        put_response = client.config.put_keyset({"source": source, "token": token})
    except ApiException as e:
        Logger.info(
            "Failed to fetch keyset: %s" % e.get_error_message(), host=client.host_uri,
        )
        raise e
    except UrlLib3ConnExceptions:
        raise ApiException(
            status=HTTPStatus.SERVICE_UNAVAILABLE,
            reason="Controller unavailable. It is likely rebooting. Try client.sys_admin.wait_for_api().",
        )

    if put_response.response.keyset_present:
        raise ApiException(status=400, reason="Keyset already exists.")

    start_time = put_response.response.started_at_i
    Logger.info(message="Keyset downloading from source.", start_time=start_time)
    polling_start = time.time()
    while time.time() - polling_start <= wait_timeout:
        try:
            duplicate_call_resp = client.config.put_keyset(
                {"source": source, "token": token}
            )
        except UrlLib3ConnExceptions:
            Logger.info(
                "API call timeout. Controller is likely rebooting. Waiting for keyset.",
                wait_timeout=wait_timeout,
            )
            client.sys_admin.wait_for_api(timeout=wait_timeout, wait_for_reboot=True)
            return client.config.wait_for_keyset(timeout=wait_timeout)
        except ApiException as e:
            duplicate_call_error = e.get_error_message()

            if duplicate_call_error == "Keyset already exists.":
                keyset_data = client.config.try_get_keyset()
                if not keyset_data:
                    Logger.info(
                        "Keyset exists. Waiting for reboot.", wait_timeout=wait_timeout
                    )
                    client.sys_admin.wait_for_api(
                        timeout=wait_timeout, wait_for_reboot=True
                    )
                    return client.config.wait_for_keyset()
                return keyset_data

            if duplicate_call_error == "Keyset setup in progress.":
                # this means download is in progress, but might fail. Wait and retry
                time.sleep(2.0)
                continue

            # Unexpected ApiException
            raise e

        # If there is a new start time for keyset generation, that indicates a failure
        new_start = duplicate_call_resp.response.started_at_i
        if (new_start and start_time) and (new_start != start_time):
            Logger.error(failure_error_str, source=source)
            raise ApiException(status=HTTPStatus.BAD_REQUEST, reason=failure_error_str)

    raise CohesiveSDKException(
        "Timeout while waiting for keyset.", host=client.host_uri, source=source
    )


def setup_controller(
    client: VNS3Client,
    topology_name: str,
    license_file: str,
    license_parameters: Dict,
    keyset_parameters: Dict,
    peering_id: int = 1,
    reboot_timeout=120,
    keyset_timeout=120,
):
    """setup_controller Set the topology name, controller license, keyset and peering ID if provided

    Arguments:
        client {VNS3Client}
        topology_name {str}
        keyset_parameters {Dict} -- UpdateKeysetRequest {
            'source': 'str',
            'token': 'str',
            'topology_name': 'str',
            'sealed_network': 'bool'
        }
        peering_id {int} -- ID for this controller in peering mesh

    Returns:
        OperationResult
    """
    current_config = client.config.get_config().response
    Logger.info("Setting topology name", name=topology_name)
    if current_config.topology_name != topology_name:
        client.config.put_config({"topology_name": topology_name})

    if not current_config.licensed:
        if not os.path.isfile(license_file):
            raise CohesiveSDKException("License file does not exist")

        license_file_data = open(license_file).read().strip()
        Logger.info("Uploading license file", path=license_file)
        client.licensing.upload_license(license_file_data)

    accept_license = False
    try:
        current_license = client.licensing.get_license().response
        accept_license = not current_license or not current_license.finalized
    except ApiException as e:
        if e.get_error_message() == "Must be licensed first.":
            accept_license = True
        else:
            raise e

    if accept_license:
        Logger.info("Accepting license", parameters=license_parameters)
        client.licensing.put_set_license_parameters(license_parameters)
        Logger.info("Waiting for server reboot.")
        client.sys_admin.wait_for_api(timeout=reboot_timeout, wait_for_reboot=True)

    current_keyset = api_operations.retry_call(
        client.config.get_keyset, max_attempts=20
    ).response
    if not current_keyset.keyset_present and not current_keyset.in_progress:
        Logger.info("Generating keyset", parameters=keyset_parameters)
        api_operations.retry_call(client.config.put_keyset, args=(keyset_parameters,))
        Logger.info("Waiting for keyset ready")
        client.config.wait_for_keyset(timeout=keyset_timeout)
    elif current_keyset.in_progress:
        client.config.wait_for_keyset(timeout=keyset_timeout)

    current_peering_status = client.peering.get_peering_status().response
    if not current_peering_status.id and peering_id:
        Logger.info("Setting peering id", id=peering_id)
        client.peering.put_self_peering_id({"id": peering_id})
    return client


def license_clients(clients, license_file_path) -> data_types.BulkOperationResult:
    """Upload license file to all clients. These will have DIFFERENT keysets. See keyset operations
       if all controllers are to be in the same clientpack topology

    Arguments:
        clients {List[VNS3Client]}
        license_file_path {str} - full path to license file

    Returns:
        BulkOperationResult
    """
    license_file = open(license_file_path).read().strip()

    def _upload_license(_client):
        return _client.licensing.upload_license(license_file)

    return api_operations.__bulk_call_client(clients, _upload_license)


def accept_clients_license(
    clients, license_parameters
) -> data_types.BulkOperationResult:
    """Accept licenses for all. These will have DIFFERENT keysets. See keyset operations
       if all controllers are to be in the same clientpack topology. Assumes same license
       parameters will be accepted for all clients

    Arguments:
        clients {List[VNS3Client]}
        license_parameters {UpdateLicenseParametersRequest} - dict {
            'subnet': 'str',
            'managers': 'str',
            'asns': 'str',
            'clients': 'str',
            'my_manager_vip': 'str',
            'default': 'bool'
        }

    Returns:
        BulkOperationResult
    """

    def _accept_license(_client):
        return _client.licensing.put_set_license_parameters(license_parameters)

    return api_operations.__bulk_call_client(clients, _accept_license)


def fetch_keysets(clients, root_host, keyset_token, wait_timeout=80.0):
    """fetch_keysets Fetch keysets for all clients from root_host

    Arguments:
        clients {List[VNS3Client]}
        root_host {str}
        keyset_token {str}

    Returns:
        BulkOperationResult
    """

    def _fetch_keyset(_client):
        return fetch_keyset_from_source(
            _client, root_host, keyset_token, wait_timeout=wait_timeout
        )

    return api_operations.__bulk_call_client(clients, _fetch_keyset, parallelize=True)



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

from tests.rest_mock import RestClientMock

from cohesivenet import VNS3Client, models, Configuration
from cohesivenet.rest import ApiException


class TestHighAvailabilityApi(object):
    """HighAvailabilityApi unit test stubs"""

    def test_get_ha_id(self, rest_mock: RestClientMock):
        """Test case for get_ha_id

        """
        mock_uuid = "4902a793073191235f83ae25c83a596b4277c8a6c909ecf9551ce8cd3189b12d"
        rest_mock.stub_request(
            "get", "/api/ha/uuid", {"response": {"ha_uuid": mock_uuid}}
        )

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.high_availability.get_ha_id()
        assert type(resp) is models.HaUUID
        assert resp.response.ha_uuid == mock_uuid

    def test_get_ha_status_uninitialized(self, rest_mock: RestClientMock):
        """Test case for get_ha_status

        """
        method, uri = "get", "/api/ha/status"
        mock_uuid = "4902a793073191235f83ae25c83a596b4277c8a6c909ecf9551ce8cd3189b12d"
        rest_mock.stub_request(
            method,
            uri,
            {"response": {"type": "backup_server", "status": "Not initialised"}},
        )

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.high_availability.get_ha_status(mock_uuid)
        assert type(resp) is models.HaDetail
        assert resp.response.type == "backup_server"
        assert resp.response.status == "Not initialised"
        rest_mock.assert_requested(method, uri, query_params=[("uuid", mock_uuid)])

    @pytest.mark.licensed
    def test_get_ha_sync_file(self, rest_mock: RestClientMock):
        """Test case for get_ha_sync_file

        """
        pass

    @pytest.mark.licensed
    def test_get_ha_sync_status(self, rest_mock: RestClientMock):
        """Test case for get_ha_sync_status

        """
        pass

    def test_post_init_ha(self, rest_mock: RestClientMock):
        """Test case for post_init_ha

        """
        pass

    @pytest.mark.licensed
    def test_post_sync_ha(self, rest_mock: RestClientMock):
        """Test case for post_sync_ha

        """
        pass

    def test_put_ha_activate(self, rest_mock: RestClientMock):
        """Test case for put_ha_activate

        """
        pass

    def test_put_ha_push_file(self, rest_mock: RestClientMock):
        """Test case for put_ha_push_file

        """
        pass



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class UpdateIpsecConnectionRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "ipaddress": "str",
        "secret": "str",
        "pfs": "bool",
        "ike_version": "int",
        "nat_t_enabled": "bool",
        "extra_config": "str",
        "private_ipaddress": "str",
        "gre": "bool",
        "gre_interface_address": "str",
        "vpn_type": "str",
        "route_based_int_address": "str",
        "route_based_local": "str",
        "route_based_remote": "str",
    }

    attribute_map = {
        "name": "name",
        "ipaddress": "ipaddress",
        "secret": "secret",
        "pfs": "pfs",
        "ike_version": "ike_version",
        "nat_t_enabled": "nat_t_enabled",
        "extra_config": "extra_config",
        "private_ipaddress": "private_ipaddress",
        "gre": "gre",
        "gre_interface_address": "gre_interface_address",
        "vpn_type": "vpn_type",
        "route_based_int_address": "route_based_int_address",
        "route_based_local": "route_based_local",
        "route_based_remote": "route_based_remote",
    }

    def __init__(
        self,
        name=None,
        ipaddress=None,
        secret=None,
        pfs=None,
        ike_version=None,
        nat_t_enabled=None,
        extra_config=None,
        private_ipaddress=None,
        gre=None,
        gre_interface_address=None,
        vpn_type=None,
        route_based_int_address=None,
        route_based_local=None,
        route_based_remote=None,
    ):  # noqa: E501
        """UpdateIpsecConnectionRequest - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._ipaddress = None
        self._secret = None
        self._pfs = None
        self._ike_version = None
        self._nat_t_enabled = None
        self._extra_config = None
        self._private_ipaddress = None
        self._gre = None
        self._gre_interface_address = None
        self._vpn_type = None
        self._route_based_int_address = None
        self._route_based_local = None
        self._route_based_remote = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if ipaddress is not None:
            self.ipaddress = ipaddress
        if secret is not None:
            self.secret = secret
        if pfs is not None:
            self.pfs = pfs
        if ike_version is not None:
            self.ike_version = ike_version
        if nat_t_enabled is not None:
            self.nat_t_enabled = nat_t_enabled
        if extra_config is not None:
            self.extra_config = extra_config
        if private_ipaddress is not None:
            self.private_ipaddress = private_ipaddress
        if gre is not None:
            self.gre = gre
        if gre_interface_address is not None:
            self.gre_interface_address = gre_interface_address
        if vpn_type is not None:
            self.vpn_type = vpn_type
        if route_based_int_address is not None:
            self.route_based_int_address = route_based_int_address
        if route_based_local is not None:
            self.route_based_local = route_based_local
        if route_based_remote is not None:
            self.route_based_remote = route_based_remote

    @property
    def name(self):
        """Gets the name of this UpdateIpsecConnectionRequest.  # noqa: E501

        Name for the connection.  # noqa: E501

        :return: The name of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateIpsecConnectionRequest.

        Name for the connection.  # noqa: E501

        :param name: The name of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def ipaddress(self):
        """Gets the ipaddress of this UpdateIpsecConnectionRequest.  # noqa: E501

        IP of the remote gateway  # noqa: E501

        :return: The ipaddress of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._ipaddress

    @ipaddress.setter
    def ipaddress(self, ipaddress):
        """Sets the ipaddress of this UpdateIpsecConnectionRequest.

        IP of the remote gateway  # noqa: E501

        :param ipaddress: The ipaddress of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._ipaddress = ipaddress

    @property
    def secret(self):
        """Gets the secret of this UpdateIpsecConnectionRequest.  # noqa: E501

        Pre-shared key  # noqa: E501

        :return: The secret of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this UpdateIpsecConnectionRequest.

        Pre-shared key  # noqa: E501

        :param secret: The secret of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._secret = secret

    @property
    def pfs(self):
        """Gets the pfs of this UpdateIpsecConnectionRequest.  # noqa: E501

        Perfect Forward Secrecy if true, disables if false.  # noqa: E501

        :return: The pfs of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._pfs

    @pfs.setter
    def pfs(self, pfs):
        """Sets the pfs of this UpdateIpsecConnectionRequest.

        Perfect Forward Secrecy if true, disables if false.  # noqa: E501

        :param pfs: The pfs of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: bool
        """

        self._pfs = pfs

    @property
    def ike_version(self):
        """Gets the ike_version of this UpdateIpsecConnectionRequest.  # noqa: E501

        Version for IKE algorithm  # noqa: E501

        :return: The ike_version of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: int
        """
        return self._ike_version

    @ike_version.setter
    def ike_version(self, ike_version):
        """Sets the ike_version of this UpdateIpsecConnectionRequest.

        Version for IKE algorithm  # noqa: E501

        :param ike_version: The ike_version of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2]  # noqa: E501
        if ike_version not in allowed_values:
            raise ValueError(
                "Invalid value for `ike_version` ({0}), must be one of {1}".format(  # noqa: E501
                    ike_version, allowed_values
                )
            )

        self._ike_version = ike_version

    @property
    def nat_t_enabled(self):
        """Gets the nat_t_enabled of this UpdateIpsecConnectionRequest.  # noqa: E501

        True if you want encapsulated IPsec protocol to this gateway  # noqa: E501

        :return: The nat_t_enabled of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._nat_t_enabled

    @nat_t_enabled.setter
    def nat_t_enabled(self, nat_t_enabled):
        """Sets the nat_t_enabled of this UpdateIpsecConnectionRequest.

        True if you want encapsulated IPsec protocol to this gateway  # noqa: E501

        :param nat_t_enabled: The nat_t_enabled of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: bool
        """

        self._nat_t_enabled = nat_t_enabled

    @property
    def extra_config(self):
        """Gets the extra_config of this UpdateIpsecConnectionRequest.  # noqa: E501

        Additional optionals for connection such as 'phase1=aes256_gcm-sha2_256-dh14 phase2=aes256_gcm'  # noqa: E501

        :return: The extra_config of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._extra_config

    @extra_config.setter
    def extra_config(self, extra_config):
        """Sets the extra_config of this UpdateIpsecConnectionRequest.

        Additional optionals for connection such as 'phase1=aes256_gcm-sha2_256-dh14 phase2=aes256_gcm'  # noqa: E501

        :param extra_config: The extra_config of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._extra_config = extra_config

    @property
    def private_ipaddress(self):
        """Gets the private_ipaddress of this UpdateIpsecConnectionRequest.  # noqa: E501

        Internal NAT address of the remote gateway  # noqa: E501

        :return: The private_ipaddress of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._private_ipaddress

    @private_ipaddress.setter
    def private_ipaddress(self, private_ipaddress):
        """Sets the private_ipaddress of this UpdateIpsecConnectionRequest.

        Internal NAT address of the remote gateway  # noqa: E501

        :param private_ipaddress: The private_ipaddress of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._private_ipaddress = private_ipaddress

    @property
    def gre(self):
        """Gets the gre of this UpdateIpsecConnectionRequest.  # noqa: E501

        True if GRE is being used for the specific endpoint  # noqa: E501

        :return: The gre of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._gre

    @gre.setter
    def gre(self, gre):
        """Sets the gre of this UpdateIpsecConnectionRequest.

        True if GRE is being used for the specific endpoint  # noqa: E501

        :param gre: The gre of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: bool
        """

        self._gre = gre

    @property
    def gre_interface_address(self):
        """Gets the gre_interface_address of this UpdateIpsecConnectionRequest.  # noqa: E501

        Interface address for GRE  # noqa: E501

        :return: The gre_interface_address of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._gre_interface_address

    @gre_interface_address.setter
    def gre_interface_address(self, gre_interface_address):
        """Sets the gre_interface_address of this UpdateIpsecConnectionRequest.

        Interface address for GRE  # noqa: E501

        :param gre_interface_address: The gre_interface_address of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._gre_interface_address = gre_interface_address

    @property
    def vpn_type(self):
        """Gets the vpn_type of this UpdateIpsecConnectionRequest.  # noqa: E501

        policy, gre, vti  # noqa: E501

        :return: The vpn_type of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpn_type

    @vpn_type.setter
    def vpn_type(self, vpn_type):
        """Sets the vpn_type of this UpdateIpsecConnectionRequest.

        policy, gre, vti  # noqa: E501

        :param vpn_type: The vpn_type of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._vpn_type = vpn_type

    @property
    def route_based_int_address(self):
        """Gets the route_based_int_address of this UpdateIpsecConnectionRequest.  # noqa: E501


        :return: The route_based_int_address of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._route_based_int_address

    @route_based_int_address.setter
    def route_based_int_address(self, route_based_int_address):
        """Sets the route_based_int_address of this UpdateIpsecConnectionRequest.


        :param route_based_int_address: The route_based_int_address of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._route_based_int_address = route_based_int_address

    @property
    def route_based_local(self):
        """Gets the route_based_local of this UpdateIpsecConnectionRequest.  # noqa: E501


        :return: The route_based_local of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._route_based_local

    @route_based_local.setter
    def route_based_local(self, route_based_local):
        """Sets the route_based_local of this UpdateIpsecConnectionRequest.


        :param route_based_local: The route_based_local of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._route_based_local = route_based_local

    @property
    def route_based_remote(self):
        """Gets the route_based_remote of this UpdateIpsecConnectionRequest.  # noqa: E501


        :return: The route_based_remote of this UpdateIpsecConnectionRequest.  # noqa: E501
        :rtype: str
        """
        return self._route_based_remote

    @route_based_remote.setter
    def route_based_remote(self, route_based_remote):
        """Sets the route_based_remote of this UpdateIpsecConnectionRequest.


        :param route_based_remote: The route_based_remote of this UpdateIpsecConnectionRequest.  # noqa: E501
        :type: str
        """

        self._route_based_remote = route_based_remote

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateIpsecConnectionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cohesivenet.exceptions import ApiTypeError, ApiValueError


class InterfacesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            from cohesivenet.vns3_client import VNS3Client

            api_client = VNS3Client()
        self.api_client = api_client

    def delete_gre_endpoint(self, **kwargs):  # noqa: E501
        """delete_gre_endpoint  # noqa: E501

        Delete GRE Interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_gre_endpoint(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_gre_endpoint_with_http_info(**kwargs)  # noqa: E501

    def delete_gre_endpoint_with_http_info(self, **kwargs):  # noqa: E501
        """delete_gre_endpoint  # noqa: E501

        Delete GRE Interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_gre_endpoint_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_gre_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/edge_gre/{interface_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def delete_system_interface(self, interface_id, **kwargs):  # noqa: E501
        """delete_system_interface  # noqa: E501

        Delete System Interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_system_interface(interface_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str interface_id: ID for system interface (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_system_interface_with_http_info(
            interface_id, **kwargs
        )  # noqa: E501

    def delete_system_interface_with_http_info(
        self, interface_id, **kwargs
    ):  # noqa: E501
        """delete_system_interface  # noqa: E501

        Delete System Interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_system_interface_with_http_info(interface_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str interface_id: ID for system interface (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["interface_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_system_interface" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'interface_id' is set
        if (
            "interface_id" not in local_var_params
            or local_var_params["interface_id"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `interface_id` when calling `delete_system_interface`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "interface_id" in local_var_params:
            path_params["interface_id"] = local_var_params["interface_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/system/{interface_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_edge_gre_endpoints(self, **kwargs):  # noqa: E501
        """get_edge_gre_endpoints  # noqa: E501

        Describe system edge GRE endpoints  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_edge_gre_endpoints(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GREEndpointListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_edge_gre_endpoints_with_http_info(**kwargs)  # noqa: E501

    def get_edge_gre_endpoints_with_http_info(self, **kwargs):  # noqa: E501
        """get_edge_gre_endpoints  # noqa: E501

        Describe system edge GRE endpoints  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_edge_gre_endpoints_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GREEndpointListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_edge_gre_endpoints" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/edge_gre",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="GREEndpointListResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_gre_endpoint_details(self, interface_id, **kwargs):  # noqa: E501
        """get_gre_endpoint_details  # noqa: E501

        Get GRE interface details by id or name  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_gre_endpoint_details(interface_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str interface_id: ID for system interface (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GREEndpointDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_gre_endpoint_details_with_http_info(
            interface_id, **kwargs
        )  # noqa: E501

    def get_gre_endpoint_details_with_http_info(
        self, interface_id, **kwargs
    ):  # noqa: E501
        """get_gre_endpoint_details  # noqa: E501

        Get GRE interface details by id or name  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_gre_endpoint_details_with_http_info(interface_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str interface_id: ID for system interface (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GREEndpointDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["interface_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_gre_endpoint_details" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'interface_id' is set
        if (
            "interface_id" not in local_var_params
            or local_var_params["interface_id"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `interface_id` when calling `get_gre_endpoint_details`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "interface_id" in local_var_params:
            path_params["interface_id"] = local_var_params["interface_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/edge_gre/{interface_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="GREEndpointDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_interfaces(self, **kwargs):  # noqa: E501
        """get_interfaces  # noqa: E501

        (BETA) Describe all physical and virtual interfaces, both system and edge GRE interfaces  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_interfaces(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SystemInterfaceListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_interfaces_with_http_info(**kwargs)  # noqa: E501

    def get_interfaces_with_http_info(self, **kwargs):  # noqa: E501
        """get_interfaces  # noqa: E501

        (BETA) Describe all physical and virtual interfaces, both system and edge GRE interfaces  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_interfaces_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SystemInterfaceListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_interfaces" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SystemInterfaceListResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_system_interface_details(self, **kwargs):  # noqa: E501
        """get_system_interface_details  # noqa: E501

        Get interface details by name  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_interface_details(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_system_interface_details_with_http_info(**kwargs)  # noqa: E501

    def get_system_interface_details_with_http_info(self, **kwargs):  # noqa: E501
        """get_system_interface_details  # noqa: E501

        Get interface details by name  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_interface_details_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_interface_details" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/system/{interface_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_system_interfaces(self, **kwargs):  # noqa: E501
        """get_system_interfaces  # noqa: E501

        Describe system interfaces  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_interfaces(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_system_interfaces_with_http_info(**kwargs)  # noqa: E501

    def get_system_interfaces_with_http_info(self, **kwargs):  # noqa: E501
        """get_system_interfaces  # noqa: E501

        Describe system interfaces  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_interfaces_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_interfaces" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/system",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_action_interfaces(self, interface_action_request, **kwargs):  # noqa: E501
        """post_action_interfaces  # noqa: E501

        Take action on interfaces. Only one action can be taken per request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_action_interfaces(interface_action_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param InterfaceActionRequest interface_action_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_action_interfaces_with_http_info(
            interface_action_request, **kwargs
        )  # noqa: E501

    def post_action_interfaces_with_http_info(
        self, interface_action_request, **kwargs
    ):  # noqa: E501
        """post_action_interfaces  # noqa: E501

        Take action on interfaces. Only one action can be taken per request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_action_interfaces_with_http_info(interface_action_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param InterfaceActionRequest interface_action_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[str], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["interface_action_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_action_interfaces" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'interface_action_request' is set
        if (
            "interface_action_request" not in local_var_params
            or local_var_params["interface_action_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `interface_action_request` when calling `post_action_interfaces`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "interface_action_request" in local_var_params:
            body_params = local_var_params["interface_action_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/action",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[str]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_create_gre_endpoint(self, body, **kwargs):  # noqa: E501
        """post_create_gre_endpoint  # noqa: E501

        Create new edge GRE interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_gre_endpoint(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_create_gre_endpoint_with_http_info(
            body, **kwargs
        )  # noqa: E501

    def post_create_gre_endpoint_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_create_gre_endpoint  # noqa: E501

        Create new edge GRE interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_gre_endpoint_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_create_gre_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in local_var_params or local_var_params["body"] is None:
            raise ApiValueError(
                "Missing the required parameter `body` when calling `post_create_gre_endpoint`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in local_var_params:
            body_params = local_var_params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/edge_gre",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_create_system_interface(self, body, **kwargs):  # noqa: E501
        """post_create_system_interface  # noqa: E501

        Create new system interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_system_interface(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SystemInterfaceDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_create_system_interface_with_http_info(
            body, **kwargs
        )  # noqa: E501

    def post_create_system_interface_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_create_system_interface  # noqa: E501

        Create new system interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_system_interface_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SystemInterfaceDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_create_system_interface" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in local_var_params or local_var_params["body"] is None:
            raise ApiValueError(
                "Missing the required parameter `body` when calling `post_create_system_interface`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in local_var_params:
            body_params = local_var_params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/system",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SystemInterfaceDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_update_gre_endpoint(self, body, **kwargs):  # noqa: E501
        """put_update_gre_endpoint  # noqa: E501

        Update GRE interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_gre_endpoint(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_update_gre_endpoint_with_http_info(body, **kwargs)  # noqa: E501

    def put_update_gre_endpoint_with_http_info(self, body, **kwargs):  # noqa: E501
        """put_update_gre_endpoint  # noqa: E501

        Update GRE interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_gre_endpoint_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_update_gre_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in local_var_params or local_var_params["body"] is None:
            raise ApiValueError(
                "Missing the required parameter `body` when calling `put_update_gre_endpoint`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in local_var_params:
            body_params = local_var_params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/edge_gre/{interface_id}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_update_system_interface(self, body, **kwargs):  # noqa: E501
        """put_update_system_interface  # noqa: E501

        Update system interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_system_interface(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_update_system_interface_with_http_info(
            body, **kwargs
        )  # noqa: E501

    def put_update_system_interface_with_http_info(self, body, **kwargs):  # noqa: E501
        """put_update_system_interface  # noqa: E501

        Update system interface  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_update_system_interface_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param object body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_update_system_interface" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in local_var_params or local_var_params["body"] is None:
            raise ApiValueError(
                "Missing the required parameter `body` when calling `put_update_system_interface`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in local_var_params:
            body_params = local_var_params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/interfaces/system/{interface_id}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class UpdateIpsecTunnelRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "bounce": "bool",
        "description": "str",
        "remote_subnet": "str",
        "local_subnet": "str",
        "ping_ipaddress": "str",
        "ping_interval": "int",
        "ping_interface": "str",
        "enabled": "bool",
    }

    attribute_map = {
        "bounce": "bounce",
        "description": "description",
        "remote_subnet": "remote_subnet",
        "local_subnet": "local_subnet",
        "ping_ipaddress": "ping_ipaddress",
        "ping_interval": "ping_interval",
        "ping_interface": "ping_interface",
        "enabled": "enabled",
    }

    def __init__(
        self,
        bounce=False,
        description=None,
        remote_subnet=None,
        local_subnet=None,
        ping_ipaddress=None,
        ping_interval=None,
        ping_interface=None,
        enabled=None,
    ):  # noqa: E501
        """UpdateIpsecTunnelRequest - a model defined in OpenAPI"""  # noqa: E501

        self._bounce = None
        self._description = None
        self._remote_subnet = None
        self._local_subnet = None
        self._ping_ipaddress = None
        self._ping_interval = None
        self._ping_interface = None
        self._enabled = None
        self.discriminator = None

        if bounce is not None:
            self.bounce = bounce
        if description is not None:
            self.description = description
        if remote_subnet is not None:
            self.remote_subnet = remote_subnet
        if local_subnet is not None:
            self.local_subnet = local_subnet
        if ping_ipaddress is not None:
            self.ping_ipaddress = ping_ipaddress
        if ping_interval is not None:
            self.ping_interval = ping_interval
        if ping_interface is not None:
            self.ping_interface = ping_interface
        if enabled is not None:
            self.enabled = enabled

    @property
    def bounce(self):
        """Gets the bounce of this UpdateIpsecTunnelRequest.  # noqa: E501

        Resets the IPsec connection for this specific tunnel  # noqa: E501

        :return: The bounce of this UpdateIpsecTunnelRequest.  # noqa: E501
        :rtype: bool
        """
        return self._bounce

    @bounce.setter
    def bounce(self, bounce):
        """Sets the bounce of this UpdateIpsecTunnelRequest.

        Resets the IPsec connection for this specific tunnel  # noqa: E501

        :param bounce: The bounce of this UpdateIpsecTunnelRequest.  # noqa: E501
        :type: bool
        """

        self._bounce = bounce

    @property
    def description(self):
        """Gets the description of this UpdateIpsecTunnelRequest.  # noqa: E501


        :return: The description of this UpdateIpsecTunnelRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateIpsecTunnelRequest.


        :param description: The description of this UpdateIpsecTunnelRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def remote_subnet(self):
        """Gets the remote_subnet of this UpdateIpsecTunnelRequest.  # noqa: E501

        Remote subnet for tunnel in CIDR notation  # noqa: E501

        :return: The remote_subnet of this UpdateIpsecTunnelRequest.  # noqa: E501
        :rtype: str
        """
        return self._remote_subnet

    @remote_subnet.setter
    def remote_subnet(self, remote_subnet):
        """Sets the remote_subnet of this UpdateIpsecTunnelRequest.

        Remote subnet for tunnel in CIDR notation  # noqa: E501

        :param remote_subnet: The remote_subnet of this UpdateIpsecTunnelRequest.  # noqa: E501
        :type: str
        """

        self._remote_subnet = remote_subnet

    @property
    def local_subnet(self):
        """Gets the local_subnet of this UpdateIpsecTunnelRequest.  # noqa: E501

        Local subnet for tunnel in CIDR notation  # noqa: E501

        :return: The local_subnet of this UpdateIpsecTunnelRequest.  # noqa: E501
        :rtype: str
        """
        return self._local_subnet

    @local_subnet.setter
    def local_subnet(self, local_subnet):
        """Sets the local_subnet of this UpdateIpsecTunnelRequest.

        Local subnet for tunnel in CIDR notation  # noqa: E501

        :param local_subnet: The local_subnet of this UpdateIpsecTunnelRequest.  # noqa: E501
        :type: str
        """

        self._local_subnet = local_subnet

    @property
    def ping_ipaddress(self):
        """Gets the ping_ipaddress of this UpdateIpsecTunnelRequest.  # noqa: E501

        Exo Ping feature - remote IP destination of ping  # noqa: E501

        :return: The ping_ipaddress of this UpdateIpsecTunnelRequest.  # noqa: E501
        :rtype: str
        """
        return self._ping_ipaddress

    @ping_ipaddress.setter
    def ping_ipaddress(self, ping_ipaddress):
        """Sets the ping_ipaddress of this UpdateIpsecTunnelRequest.

        Exo Ping feature - remote IP destination of ping  # noqa: E501

        :param ping_ipaddress: The ping_ipaddress of this UpdateIpsecTunnelRequest.  # noqa: E501
        :type: str
        """

        self._ping_ipaddress = ping_ipaddress

    @property
    def ping_interval(self):
        """Gets the ping_interval of this UpdateIpsecTunnelRequest.  # noqa: E501

        Exo Ping feature - periodicy of the ping in seconds  # noqa: E501

        :return: The ping_interval of this UpdateIpsecTunnelRequest.  # noqa: E501
        :rtype: int
        """
        return self._ping_interval

    @ping_interval.setter
    def ping_interval(self, ping_interval):
        """Sets the ping_interval of this UpdateIpsecTunnelRequest.

        Exo Ping feature - periodicy of the ping in seconds  # noqa: E501

        :param ping_interval: The ping_interval of this UpdateIpsecTunnelRequest.  # noqa: E501
        :type: int
        """

        self._ping_interval = ping_interval

    @property
    def ping_interface(self):
        """Gets the ping_interface of this UpdateIpsecTunnelRequest.  # noqa: E501

        Exo Ping feature - what network interface IP of the VNS3 controller to use as the source of ping  # noqa: E501

        :return: The ping_interface of this UpdateIpsecTunnelRequest.  # noqa: E501
        :rtype: str
        """
        return self._ping_interface

    @ping_interface.setter
    def ping_interface(self, ping_interface):
        """Sets the ping_interface of this UpdateIpsecTunnelRequest.

        Exo Ping feature - what network interface IP of the VNS3 controller to use as the source of ping  # noqa: E501

        :param ping_interface: The ping_interface of this UpdateIpsecTunnelRequest.  # noqa: E501
        :type: str
        """

        self._ping_interface = ping_interface

    @property
    def enabled(self):
        """Gets the enabled of this UpdateIpsecTunnelRequest.  # noqa: E501

        Disables tunnel if set to false  # noqa: E501

        :return: The enabled of this UpdateIpsecTunnelRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this UpdateIpsecTunnelRequest.

        Disables tunnel if set to false  # noqa: E501

        :param enabled: The enabled of this UpdateIpsecTunnelRequest.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateIpsecTunnelRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.network_edge_plugins_api import (
    NetworkEdgePluginsApi,
)  # noqa: E501
from cohesivenet.rest import ApiException


@pytest.mark.licensed
class TestNetworkEdgePluginsApi(object):
    """NetworkEdgePluginsApi unit test stubs"""

    def test_delete_container(self):
        """Test case for delete_container

        """
        pass

    def test_delete_container_image(self):
        """Test case for delete_container_image

        """
        pass

    def test_get_container_logs(self):
        """Test case for get_container_logs

        """
        pass

    def test_get_container_system_i_ps(self):
        """Test case for get_container_system_i_ps

        """
        pass

    def test_get_container_system_images(self):
        """Test case for get_container_system_images

        """
        pass

    def test_get_container_system_running_containers(self):
        """Test case for get_container_system_running_containers

        """
        pass

    def test_get_container_system_status(self):
        """Test case for get_container_system_status

        """
        pass

    def test_post_action_container_system(self):
        """Test case for post_action_container_system

        """
        pass

    def test_post_commit_container(self):
        """Test case for post_commit_container

        """
        pass

    def test_post_create_container_image(self):
        """Test case for post_create_container_image

        """
        pass

    def test_post_start_container(self):
        """Test case for post_start_container

        """
        pass

    def test_put_configure_container_system(self):
        """Test case for put_configure_container_system

        """
        pass

    def test_put_edit_container_image(self):
        """Test case for put_edit_container_image

        """
        pass

    def test_put_stop_container(self):
        """Test case for put_stop_container

        """
        pass



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.ipsec_api import IPsecApi  # noqa: E501
from cohesivenet.rest import ApiException


@pytest.mark.licensed
class TestIPsecApi(object):
    """IPsecApi unit test stubs"""

    def test_delete_ipsec_endpoint(self):
        """Test case for delete_ipsec_endpoint

        """
        pass

    def test_delete_ipsec_endpoint_tunnel(self):
        """Test case for delete_ipsec_endpoint_tunnel

        """
        pass

    def test_get_ipsec(self):
        """Test case for get_ipsec

        """
        pass

    def test_get_ipsec_endpoint(self):
        """Test case for get_ipsec_endpoint

        """
        pass

    def test_get_ipsec_status(self):
        """Test case for get_ipsec_status

        """
        pass

    def test_get_link_history(self):
        """Test case for get_link_history

        """
        pass

    def test_post_create_ipsec_endpoint(self):
        """Test case for post_create_ipsec_endpoint

        """
        pass

    def test_post_create_ipsec_endpoint_tunnel(self):
        """Test case for post_create_ipsec_endpoint_tunnel

        """
        pass

    def test_post_restart_ipsec_action(self):
        """Test case for post_restart_ipsec_action

        """
        pass

    def test_put_edit_ipsec_endpoint(self):
        """Test case for put_edit_ipsec_endpoint

        """
        pass

    def test_put_edit_ipsec_endpoint_tunnel(self):
        """Test case for put_edit_ipsec_endpoint_tunnel

        """
        pass

    def test_put_ipsec_config(self):
        """Test case for put_ipsec_config

        """
        pass



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class LinkHistory(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "remote": "str",
        "local": "str",
        "tunnelid": "int",
        "history": "list[LinkEvent]",
    }

    attribute_map = {
        "remote": "remote",
        "local": "local",
        "tunnelid": "tunnelid",
        "history": "history",
    }

    def __init__(
        self, remote=None, local=None, tunnelid=None, history=None
    ):  # noqa: E501
        """LinkHistory - a model defined in OpenAPI"""  # noqa: E501

        self._remote = None
        self._local = None
        self._tunnelid = None
        self._history = None
        self.discriminator = None

        if remote is not None:
            self.remote = remote
        if local is not None:
            self.local = local
        if tunnelid is not None:
            self.tunnelid = tunnelid
        if history is not None:
            self.history = history

    @property
    def remote(self):
        """Gets the remote of this LinkHistory.  # noqa: E501


        :return: The remote of this LinkHistory.  # noqa: E501
        :rtype: str
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this LinkHistory.


        :param remote: The remote of this LinkHistory.  # noqa: E501
        :type: str
        """

        self._remote = remote

    @property
    def local(self):
        """Gets the local of this LinkHistory.  # noqa: E501


        :return: The local of this LinkHistory.  # noqa: E501
        :rtype: str
        """
        return self._local

    @local.setter
    def local(self, local):
        """Sets the local of this LinkHistory.


        :param local: The local of this LinkHistory.  # noqa: E501
        :type: str
        """

        self._local = local

    @property
    def tunnelid(self):
        """Gets the tunnelid of this LinkHistory.  # noqa: E501


        :return: The tunnelid of this LinkHistory.  # noqa: E501
        :rtype: int
        """
        return self._tunnelid

    @tunnelid.setter
    def tunnelid(self, tunnelid):
        """Sets the tunnelid of this LinkHistory.


        :param tunnelid: The tunnelid of this LinkHistory.  # noqa: E501
        :type: int
        """

        self._tunnelid = tunnelid

    @property
    def history(self):
        """Gets the history of this LinkHistory.  # noqa: E501


        :return: The history of this LinkHistory.  # noqa: E501
        :rtype: list[LinkEvent]
        """
        return self._history

    @history.setter
    def history(self, history):
        """Sets the history of this LinkHistory.


        :param history: The history of this LinkHistory.  # noqa: E501
        :type: list[LinkEvent]
        """

        self._history = history

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LinkHistory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ClientPack(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "overlay_ipaddress": "str",
        "linux_onefile": "str",
        "enabled": "bool",
        "conf_sha1": "str",
        "windows_onefile": "str",
        "ovpn_sha1": "str",
        "tarball_file": "str",
        "tarball_sha1": "str",
        "sequential_id": "int",
        "checked_out": "bool",
        "zip_sha1": "str",
        "zip_file": "str",
        "last_connect": "str",
        "last_disconnect": "str",
        "connected": "bool",
        "manager_id": "str",
        "ipaddress": "str",
        "tags": "dict(str, str)",
    }

    attribute_map = {
        "name": "name",
        "overlay_ipaddress": "overlay_ipaddress",
        "linux_onefile": "linux_onefile",
        "enabled": "enabled",
        "conf_sha1": "conf_sha1",
        "windows_onefile": "windows_onefile",
        "ovpn_sha1": "ovpn_sha1",
        "tarball_file": "tarball_file",
        "tarball_sha1": "tarball_sha1",
        "sequential_id": "sequential_id",
        "checked_out": "checked_out",
        "zip_sha1": "zip_sha1",
        "zip_file": "zip_file",
        "last_connect": "last_connect",
        "last_disconnect": "last_disconnect",
        "connected": "connected",
        "manager_id": "manager_id",
        "ipaddress": "ipaddress",
        "tags": "tags",
    }

    def __init__(
        self,
        name=None,
        overlay_ipaddress=None,
        linux_onefile=None,
        enabled=None,
        conf_sha1=None,
        windows_onefile=None,
        ovpn_sha1=None,
        tarball_file=None,
        tarball_sha1=None,
        sequential_id=None,
        checked_out=None,
        zip_sha1=None,
        zip_file=None,
        last_connect=None,
        last_disconnect=None,
        connected=None,
        manager_id=None,
        ipaddress=None,
        tags=None,
    ):  # noqa: E501
        """ClientPack - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._overlay_ipaddress = None
        self._linux_onefile = None
        self._enabled = None
        self._conf_sha1 = None
        self._windows_onefile = None
        self._ovpn_sha1 = None
        self._tarball_file = None
        self._tarball_sha1 = None
        self._sequential_id = None
        self._checked_out = None
        self._zip_sha1 = None
        self._zip_file = None
        self._last_connect = None
        self._last_disconnect = None
        self._connected = None
        self._manager_id = None
        self._ipaddress = None
        self._tags = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if overlay_ipaddress is not None:
            self.overlay_ipaddress = overlay_ipaddress
        if linux_onefile is not None:
            self.linux_onefile = linux_onefile
        if enabled is not None:
            self.enabled = enabled
        if conf_sha1 is not None:
            self.conf_sha1 = conf_sha1
        if windows_onefile is not None:
            self.windows_onefile = windows_onefile
        if ovpn_sha1 is not None:
            self.ovpn_sha1 = ovpn_sha1
        if tarball_file is not None:
            self.tarball_file = tarball_file
        if tarball_sha1 is not None:
            self.tarball_sha1 = tarball_sha1
        if sequential_id is not None:
            self.sequential_id = sequential_id
        if checked_out is not None:
            self.checked_out = checked_out
        if zip_sha1 is not None:
            self.zip_sha1 = zip_sha1
        if zip_file is not None:
            self.zip_file = zip_file
        if last_connect is not None:
            self.last_connect = last_connect
        if last_disconnect is not None:
            self.last_disconnect = last_disconnect
        if connected is not None:
            self.connected = connected
        if manager_id is not None:
            self.manager_id = manager_id
        if ipaddress is not None:
            self.ipaddress = ipaddress
        if tags is not None:
            self.tags = tags

    @property
    def name(self):
        """Gets the name of this ClientPack.  # noqa: E501


        :return: The name of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ClientPack.


        :param name: The name of this ClientPack.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def overlay_ipaddress(self):
        """Gets the overlay_ipaddress of this ClientPack.  # noqa: E501


        :return: The overlay_ipaddress of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._overlay_ipaddress

    @overlay_ipaddress.setter
    def overlay_ipaddress(self, overlay_ipaddress):
        """Sets the overlay_ipaddress of this ClientPack.


        :param overlay_ipaddress: The overlay_ipaddress of this ClientPack.  # noqa: E501
        :type: str
        """

        self._overlay_ipaddress = overlay_ipaddress

    @property
    def linux_onefile(self):
        """Gets the linux_onefile of this ClientPack.  # noqa: E501


        :return: The linux_onefile of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._linux_onefile

    @linux_onefile.setter
    def linux_onefile(self, linux_onefile):
        """Sets the linux_onefile of this ClientPack.


        :param linux_onefile: The linux_onefile of this ClientPack.  # noqa: E501
        :type: str
        """

        self._linux_onefile = linux_onefile

    @property
    def enabled(self):
        """Gets the enabled of this ClientPack.  # noqa: E501


        :return: The enabled of this ClientPack.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ClientPack.


        :param enabled: The enabled of this ClientPack.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def conf_sha1(self):
        """Gets the conf_sha1 of this ClientPack.  # noqa: E501


        :return: The conf_sha1 of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._conf_sha1

    @conf_sha1.setter
    def conf_sha1(self, conf_sha1):
        """Sets the conf_sha1 of this ClientPack.


        :param conf_sha1: The conf_sha1 of this ClientPack.  # noqa: E501
        :type: str
        """

        self._conf_sha1 = conf_sha1

    @property
    def windows_onefile(self):
        """Gets the windows_onefile of this ClientPack.  # noqa: E501


        :return: The windows_onefile of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._windows_onefile

    @windows_onefile.setter
    def windows_onefile(self, windows_onefile):
        """Sets the windows_onefile of this ClientPack.


        :param windows_onefile: The windows_onefile of this ClientPack.  # noqa: E501
        :type: str
        """

        self._windows_onefile = windows_onefile

    @property
    def ovpn_sha1(self):
        """Gets the ovpn_sha1 of this ClientPack.  # noqa: E501


        :return: The ovpn_sha1 of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._ovpn_sha1

    @ovpn_sha1.setter
    def ovpn_sha1(self, ovpn_sha1):
        """Sets the ovpn_sha1 of this ClientPack.


        :param ovpn_sha1: The ovpn_sha1 of this ClientPack.  # noqa: E501
        :type: str
        """

        self._ovpn_sha1 = ovpn_sha1

    @property
    def tarball_file(self):
        """Gets the tarball_file of this ClientPack.  # noqa: E501


        :return: The tarball_file of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._tarball_file

    @tarball_file.setter
    def tarball_file(self, tarball_file):
        """Sets the tarball_file of this ClientPack.


        :param tarball_file: The tarball_file of this ClientPack.  # noqa: E501
        :type: str
        """

        self._tarball_file = tarball_file

    @property
    def tarball_sha1(self):
        """Gets the tarball_sha1 of this ClientPack.  # noqa: E501


        :return: The tarball_sha1 of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._tarball_sha1

    @tarball_sha1.setter
    def tarball_sha1(self, tarball_sha1):
        """Sets the tarball_sha1 of this ClientPack.


        :param tarball_sha1: The tarball_sha1 of this ClientPack.  # noqa: E501
        :type: str
        """

        self._tarball_sha1 = tarball_sha1

    @property
    def sequential_id(self):
        """Gets the sequential_id of this ClientPack.  # noqa: E501


        :return: The sequential_id of this ClientPack.  # noqa: E501
        :rtype: int
        """
        return self._sequential_id

    @sequential_id.setter
    def sequential_id(self, sequential_id):
        """Sets the sequential_id of this ClientPack.


        :param sequential_id: The sequential_id of this ClientPack.  # noqa: E501
        :type: int
        """

        self._sequential_id = sequential_id

    @property
    def checked_out(self):
        """Gets the checked_out of this ClientPack.  # noqa: E501


        :return: The checked_out of this ClientPack.  # noqa: E501
        :rtype: bool
        """
        return self._checked_out

    @checked_out.setter
    def checked_out(self, checked_out):
        """Sets the checked_out of this ClientPack.


        :param checked_out: The checked_out of this ClientPack.  # noqa: E501
        :type: bool
        """

        self._checked_out = checked_out

    @property
    def zip_sha1(self):
        """Gets the zip_sha1 of this ClientPack.  # noqa: E501


        :return: The zip_sha1 of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._zip_sha1

    @zip_sha1.setter
    def zip_sha1(self, zip_sha1):
        """Sets the zip_sha1 of this ClientPack.


        :param zip_sha1: The zip_sha1 of this ClientPack.  # noqa: E501
        :type: str
        """

        self._zip_sha1 = zip_sha1

    @property
    def zip_file(self):
        """Gets the zip_file of this ClientPack.  # noqa: E501


        :return: The zip_file of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._zip_file

    @zip_file.setter
    def zip_file(self, zip_file):
        """Sets the zip_file of this ClientPack.


        :param zip_file: The zip_file of this ClientPack.  # noqa: E501
        :type: str
        """

        self._zip_file = zip_file

    @property
    def last_connect(self):
        """Gets the last_connect of this ClientPack.  # noqa: E501


        :return: The last_connect of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._last_connect

    @last_connect.setter
    def last_connect(self, last_connect):
        """Sets the last_connect of this ClientPack.


        :param last_connect: The last_connect of this ClientPack.  # noqa: E501
        :type: str
        """

        self._last_connect = last_connect

    @property
    def last_disconnect(self):
        """Gets the last_disconnect of this ClientPack.  # noqa: E501


        :return: The last_disconnect of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._last_disconnect

    @last_disconnect.setter
    def last_disconnect(self, last_disconnect):
        """Sets the last_disconnect of this ClientPack.


        :param last_disconnect: The last_disconnect of this ClientPack.  # noqa: E501
        :type: str
        """

        self._last_disconnect = last_disconnect

    @property
    def connected(self):
        """Gets the connected of this ClientPack.  # noqa: E501


        :return: The connected of this ClientPack.  # noqa: E501
        :rtype: bool
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """Sets the connected of this ClientPack.


        :param connected: The connected of this ClientPack.  # noqa: E501
        :type: bool
        """

        self._connected = connected

    @property
    def manager_id(self):
        """Gets the manager_id of this ClientPack.  # noqa: E501


        :return: The manager_id of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._manager_id

    @manager_id.setter
    def manager_id(self, manager_id):
        """Sets the manager_id of this ClientPack.


        :param manager_id: The manager_id of this ClientPack.  # noqa: E501
        :type: str
        """

        self._manager_id = manager_id

    @property
    def ipaddress(self):
        """Gets the ipaddress of this ClientPack.  # noqa: E501


        :return: The ipaddress of this ClientPack.  # noqa: E501
        :rtype: str
        """
        return self._ipaddress

    @ipaddress.setter
    def ipaddress(self, ipaddress):
        """Sets the ipaddress of this ClientPack.


        :param ipaddress: The ipaddress of this ClientPack.  # noqa: E501
        :type: str
        """

        self._ipaddress = ipaddress

    @property
    def tags(self):
        """Gets the tags of this ClientPack.  # noqa: E501

        Key, value object of tags  # noqa: E501

        :return: The tags of this ClientPack.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ClientPack.

        Key, value object of tags  # noqa: E501

        :param tags: The tags of this ClientPack.  # noqa: E501
        :type: dict(str, str)
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClientPack):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class AccessTokenDetail(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"response": "AccessToken"}

    attribute_map = {"response": "response"}

    def __init__(self, response=None):  # noqa: E501
        """AccessTokenDetail - a model defined in OpenAPI"""  # noqa: E501

        self._response = None
        self.discriminator = None

        if response is not None:
            self.response = response

    @property
    def response(self):
        """Gets the response of this AccessTokenDetail.  # noqa: E501


        :return: The response of this AccessTokenDetail.  # noqa: E501
        :rtype: AccessToken
        """
        return self._response

    @response.setter
    def response(self, response):
        """Sets the response of this AccessTokenDetail.


        :param response: The response of this AccessTokenDetail.  # noqa: E501
        :type: AccessToken
        """

        self._response = response

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessTokenDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class UpdateIpsecAddressRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"ipsec_local_address": "str"}

    attribute_map = {"ipsec_local_address": "ipsec_local_address"}

    def __init__(self, ipsec_local_address=None):  # noqa: E501
        """UpdateIpsecAddressRequest - a model defined in OpenAPI"""  # noqa: E501

        self._ipsec_local_address = None
        self.discriminator = None

        self.ipsec_local_address = ipsec_local_address

    @property
    def ipsec_local_address(self):
        """Gets the ipsec_local_address of this UpdateIpsecAddressRequest.  # noqa: E501

        This is effectively a \"cloud NAT\" address, since you don't know what your LAN address  will be between invocations in a cloud, this address can be used by remote endpoints  as your \"behind a NAT\" address, sometimes referred to Peer or IKE ID, if needed (e.g. Watchguard or Juniper). It can ALSO be thought of even more simply as an IPsec \"loopback\" interface that you can use to terminate traffic.   # noqa: E501

        :return: The ipsec_local_address of this UpdateIpsecAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._ipsec_local_address

    @ipsec_local_address.setter
    def ipsec_local_address(self, ipsec_local_address):
        """Sets the ipsec_local_address of this UpdateIpsecAddressRequest.

        This is effectively a \"cloud NAT\" address, since you don't know what your LAN address  will be between invocations in a cloud, this address can be used by remote endpoints  as your \"behind a NAT\" address, sometimes referred to Peer or IKE ID, if needed (e.g. Watchguard or Juniper). It can ALSO be thought of even more simply as an IPsec \"loopback\" interface that you can use to terminate traffic.   # noqa: E501

        :param ipsec_local_address: The ipsec_local_address of this UpdateIpsecAddressRequest.  # noqa: E501
        :type: str
        """
        if ipsec_local_address is None:
            raise ValueError(
                "Invalid value for `ipsec_local_address`, must not be `None`"
            )  # noqa: E501

        self._ipsec_local_address = ipsec_local_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateIpsecAddressRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
